@@ -27,4 +27,20 @@ class VacuumTestCase < Test::Unit::TestCase
                  pgroonga_log.scan(/pgroonga: unmap.*$/),
                  pgroonga_log)
   end
+
+  test "broken object" do
+    run_sql("CREATE TABLE memos (content text);")
+    run_sql("CREATE INDEX memos_content ON memos USING pgroonga (content);")
+    run_sql("INSERT INTO memos VALUES ('PGroonga is good!');")
+    table_list = run_sql("SELECT pgroonga_command('table_list');")
+    table_list = JSON.parse(table_list[0][/^ *(\[.*)$/, 1])[1][1..-1]
+    table_name = run_sql("SELECT pgroonga_table_name('memos_content');")
+    table_name = table_name[0][/^ *(Sources.*)$/, 1]
+    table_path = table_list.find {|_, name,| name == table_name}[2]
+    table_path = File.join(@postgresql.dir, table_path)
+    run_sql("REINDEX INDEX memos_content;")
+    run_sql("SELECT pgroonga_command('database_unmap');")
+    FileUtils.rm(table_path)
+    run_sql("VACUUM memos;")
+  end
 end
